ParseRule

Trait ParseRule 

pub trait ParseRule {
    // Required method
    fn parse_rule(&self) -> bool;
}
Trait for parsing rules related to operating system and architecture.

Required Methods

fn parse_rule(&self) -> bool

Parses the rules and determines if the current environment is allowed.

Returns

A boolean indicating whether the current environment meets the rules.

Implementations on Foreign Types

Source

impl ParseRule for Option<Vec<Rule>>

Source

fn parse_rule(&self) -> bool

Parses the rules for an optional vector of Rule and determines if the current environment is allowed.

Returns

A boolean indicating whether the current environment meets the rules.

Source

impl ParseRule for [Rule]

Source

fn parse_rule(&self) -> bool

Parses the rules for an array of Rule and determines if the current environment is allowed.

Returns

A boolean indicating whether the current environment meets the rules.

Implementors