pub trait ParseRule {
// Required method
fn parse_rule(&self) -> bool;
}Expand description
Trait for parsing rules related to operating system and architecture.
Required Methods
Sourcefn parse_rule(&self) -> bool
fn parse_rule(&self) -> bool
Parses the rules and determines if the current environment is allowed.
Returns
A boolean indicating whether the current environment meets the rules.
Implementations on Foreign Types
Sourceimpl ParseRule for Option<Vec<Rule>>
impl ParseRule for Option<Vec<Rule>>
Sourcefn parse_rule(&self) -> bool
fn parse_rule(&self) -> bool
Parses the rules for an optional vector of Rule and determines if the current environment is allowed.
Returns
A boolean indicating whether the current environment meets the rules.
Sourceimpl ParseRule for [Rule]
impl ParseRule for [Rule]
Sourcefn parse_rule(&self) -> bool
fn parse_rule(&self) -> bool
Parses the rules for an array of Rule and determines if the current environment is allowed.
Returns
A boolean indicating whether the current environment meets the rules.